/***************************************************************************
 *   Copyright (C) 2004 by Brent Kelly                                     *
 *   hornedgod@hotmail.com                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <stdlib.h>

#include "kledconfig.h"

/* Singleton Code */
KLedConfig* KLedConfig::_instance = 0;
KLedConfig* KLedConfig::Instance() {
    if (_instance == 0) {
        _instance = new KLedConfig;
    }
    return _instance;
}

//Constructor
KLedConfig::KLedConfig() : KConfig( QString("knetworkledrc") ) {
    
    /* initialize m_devices */
    for ( int i=0; i<30;i++){
	strcpy(this->m_devices[i], "");
    }
    this->iDeviceCount = 0;
    this->m_chosenDevice = 0;
    this->m_pollRate = 0;
    this->setDevFile((char *)"/proc/net/dev");
    
}

/* set network devices file */
void KLedConfig::setDevFile(char *file) {
    this->m_devFile = file;
}

/* return network devices file */
const char* KLedConfig::getDevFile() {
    return(this->m_devFile);
}

/* add a device to the array of detected devices */
void KLedConfig::addDevice(char *device) {
    strcpy(this->m_devices[this->iDeviceCount], device);
    this->iDeviceCount++;
}

/* get detected device at index passed */
char* KLedConfig::getDevice(int i){
    return(this->m_devices[i]);
}

/* check for passed device in array of detected devices and set it in config file */
void KLedConfig::setChosenDevice(char* device){
    /* check for this device in list of detected devices */
    this->m_chosenDevice = this->compareToDetectedDevices( device );
    if ( this->m_chosenDevice ) {
	this->setGroup( QString("Preferences") );
	this->writeEntry(QString("ChosenDevice"), device);
	this->sync();
    } else {
	//Errormessage
	this->m_chosenDevice = 0;
	printf("Device '%s' not found!\n", device);
    }
}

/* return pointer to chosen network device */
const char* KLedConfig::getChosenDevice( ){

    if ( this->m_chosenDevice == 0 ){

	this->setGroup( QString("Preferences") );
	QString sTemp = this->readEntry(QString("ChosenDevice"));
	const char *chosenDevice = sTemp.ascii();
	if ( chosenDevice ) {
	    this->m_chosenDevice = this->compareToDetectedDevices( chosenDevice );
	}
    } 
    return( this->m_chosenDevice );
  
}

/* test passed device against array of detected devices, return pointer to matching device */
const char* KLedConfig::compareToDetectedDevices( const char* chosenDevice ) {	    
    for ( int i = 0; i < this->getDeviceCount(); i++ ) {
	if ( strcmp(chosenDevice, this->m_devices[i]) == 0 ) {
	    return(this->m_devices[i]);
	    break;
	}
    }
    return(NULL);
}

/* return count of detected devices */
int KLedConfig::getDeviceCount(){
    return(this->iDeviceCount);
}

/* set the interval (in milliseconds) to poll the network device for activity */
void KLedConfig::setPollRate( int rate ) {
    this->setGroup( QString("Preferences") );
    this->writeEntry(QString("PollRate"), rate);
    this->m_pollRate = rate;
    this->sync();
}

/* return the interval (in milliseconds) to poll the network device for activity */
int KLedConfig::getPollRate( ) {
    if ( !this->m_pollRate ) {
	this->setGroup( QString("Preferences") );
	if ( this->readEntry(QString("PollRate")) ) {
	    return(atoi(this->readEntry(QString("PollRate")).ascii()));
	}		
    }
    return(this->m_pollRate);    
}


KLedConfig::~ KLedConfig() {
}
