/***************************************************************************
 *   Copyright (C) 2004 by Brent Kelly                                     *
 *   hornedgod@hotmail.com                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kledsystemtray.h"
#include "knetworkled.h"
#include "kledconfig.h"
#include <kmessagebox.h>
#include <kpopupmenu.h>
#include <kglobal.h>
#include <qtooltip.h>

/* activity status icons */
#include "networkdead.xpm"
#include "network0.xpm"
#include "network1.xpm"
#include "network2.xpm"
#include "network3.xpm"
#include "networkicon.xpm"
#include "configure.xpm"

KLedSystemTray::KLedSystemTray(  )
 : KSystemTray(  )
{

    this->m_bDead = false;
    
    /* keep track of the last values to test for change */
    this->m_PrevRX = 0;
    this->m_PrevTX = 0;
    
    /* icons */
    this->m_xxxx = QPixmap(network0_xpm);
    this->m_TXxx = QPixmap(network1_xpm);
    this->m_xxRX = QPixmap(network2_xpm);
    this->m_TXRX = QPixmap(network3_xpm);
    this->m_imgDEAD = QPixmap(networkdead_xpm);
    
    this->m_PrevPixStatus = 0;
    
    /* systray icon, set it to noactivity icon */
    this->setStatus( (long)0, (long)0 );
    
    this->contextMenu()->changeTitle(-2, QPixmap( networkicon_xpm ), QString("KNetworkLED"));
    this->contextMenu()->insertItem(QIconSet(configure_xpm), QString("&Configure KNetworkLED"), this, SLOT(slot_configureKNetworkLED()) );
    //QIconSet(KGlobal::iconLoader()->loadIcon("configure",KIcon::Small));
    //this->contextMenu()->insertItem(QString("&Configure KNetworkLED"), QPixmap( networkicon_xpm), );
    //this->contextMenu()->connectItem(1, this, SLOT(slot_configureKNetworkLED()));
   
    this->show();
}

void KLedSystemTray::mouseDoubleClickEvent( QMouseEvent *me ) {
    
    me->ignore();
    emit signal_SysTrayDoubleClicked();
    
}
    
void KLedSystemTray::setDead(const char *message) {
    this->setPixmap( this->m_imgDEAD );
    this->m_bDead = true;
    QToolTip::add( this, message );
}

void KLedSystemTray::enterEvent( QEvent *event ) {
    KLedConfig *conf = KLedConfig::Instance();
    
    if ( ! this->m_bDead ) {
	/* update tool tip stuff */
	char tooltip[255];
	sprintf(tooltip, "%s:\nReceived: %d packets\nSent: %d packets",conf->getChosenDevice(), this->m_PrevTX, this->m_PrevRX);
	QToolTip::add( this, tooltip );
    }
    
}

int KLedSystemTray::setStatus( unsigned long received, unsigned long transmitted ) {
    
    this->m_bDead = false;
    
    /* signifies what icon we will use */
    int nStatus = 0;

    /* has transmitted changed? */
    if ( transmitted != this->m_PrevTX ) {
	this->m_PrevTX = transmitted;
	nStatus = 1;
    }	
		
    /* has received changed? */
    if ( received != this->m_PrevRX ) {
	this->m_PrevRX = received;
			
	/* have both changed? */
	if ( nStatus == 1 ) {
		nStatus = 3;
	} else {
		nStatus = 2;
	}
    }	
    
    /* don't keep redrawing the same icon if status hasn't changed */
    if ( nStatus != this->m_PrevPixStatus ) {
	
	switch ( nStatus ) {
	case 0:
	    this->setPixmap( this->m_xxxx );
	    break;
	case 1:
	    this->setPixmap( this->m_TXxx );
	    break;
	case 2:
	    this->setPixmap( this->m_xxRX );
	    break;
	case 3:
	    this->setPixmap( this->m_TXRX );
	    break;
	default:
	    //should return an error code here?
	    break;
	}  
	
	/* set up prevpixstatus for next go-round */
	this->m_PrevPixStatus = nStatus;
    } else {
	//signify that it hasn't changed
	return(0);
    }
    
    return(1);
}

void KLedSystemTray::slot_configureKNetworkLED() {
    this->kledconfigwindow = new KLedConfigWindow();
}

KLedSystemTray::~KLedSystemTray()
{
}


